@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: MozRegisterComponents.cpp 6961 2007-03-12 12:47:10Z chpe $
+ *  $Id: MozRegisterComponents.cpp 8084 2008-03-10 09:08:36Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -137,12 +137,14 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_CLIENTAUTHDIALOGS_CONTRACTID,
 		GtkNSSClientAuthDialogsConstructor
 	},
+#ifndef HAVE_GECKO_1_9
 	{
 		GTK_NSSDIALOGS_CLASSNAME,
 		GTK_NSSDIALOGS_CID,
 		NS_BADCERTLISTENER_CONTRACTID,
 		GtkNSSDialogsConstructor
 	},
+#endif
 	{
 		GTK_NSSDIALOGS_CLASSNAME,
 		GTK_NSSDIALOGS_CID,
@@ -296,9 +298,15 @@ mozilla_register_components (void)
 	for (guint i = 0; i < G_N_ELEMENTS (sAppComps); i++)
 	{
 		nsCOMPtr<nsIGenericFactory> componentFactory;
-		rv = NS_NewGenericFactory(getter_AddRefs(componentFactory),
-					  &(sAppComps[i]));
-		if (NS_FAILED(rv) || !componentFactory)
+		componentFactory = do_CreateInstance(NS_GENERICFACTORY_CONTRACTID);
+		if(!componentFactory)
+		{
+			g_warning ("Failed to create a generic factory for %s\n", sAppComps[i].mDescription);
+			ret = FALSE;
+			continue;
+		}
+		rv = componentFactory->SetComponentInfo(&(sAppComps[i]));
+		if (NS_FAILED(rv))
 		{
 			g_warning ("Failed to make a factory for %s\n", sAppComps[i].mDescription);
 
